==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/spellchecker/translations/spellchecker_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversation</translation>
    </message>
    <message>
        <source>SpellChecker</source>
        <translation>Vérificateur d&apos;orthographe</translation>
    </message>
    <message>
        <source>Misspelled Words Marking Options</source>
        <translation>Options de mise en valeur des mots mals orthographiés</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Gras</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Italique</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Souligné</translation>
    </message>
    <message>
        <source>Spell Checker Options</source>
        <translation>Options du correcteur orthographique</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Insensible à la casse</translation>
    </message>
    <message>
        <source>Spelling Suggestions Options</source>
        <translation>Options de suggestions orthographiques</translation>
    </message>
    <message>
        <source>Show suggestions</source>
        <translation>Afficher les suggestions</translation>
    </message>
    <message>
        <source>Maximum number of suggested words</source>
        <translation>Nombre maximum de mots suggérés</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Could not find dictionary for %1 language.</source>
        <translation>Le dictionnaire pour la langue %1 est introuvable.</translation>
    </message>
    <message>
        <source>Move to &apos;Checked&apos;</source>
        <translation>Aller à &apos;Vérifié&apos;</translation>
    </message>
    <message>
        <source>Available languages</source>
        <translation>Langues disponibles</translation>
    </message>
    <message>
        <source>Move to &apos;Available languages&apos;</source>
        <translation>Aller à &apos;Langues disponibles&apos;</translation>
    </message>
    <message>
        <source>Checked</source>
        <translation>Vérifié</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
</context>
</TS>

==> kadu_1.3.orig.tar.bz2: kadu-1.3/plugins/spellchecker/translations/spellchecker_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Conversation</translation>
    </message>
    <message>
        <source>Misspelled Words Marking Options</source>
        <translation>Options de mise en valeur des mots mals orthographiés</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Couleur</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Gras</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Italique</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Souligné</translation>
    </message>
    <message>
        <source>Spell Checker Options</source>
        <translation>Options du correcteur orthographique</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Insensible à la casse</translation>
    </message>
    <message>
        <source>Spelling Suggestions Options</source>
        <translation>Options de suggestions orthographiques</translation>
    </message>
    <message>
        <source>Show suggestions</source>
        <translation>Afficher les suggestions</translation>
    </message>
    <message>
        <source>Maximum number of suggested words</source>
        <translation>Nombre maximum de mots suggérés</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Could not find dictionary for %1 language.</source>
        <translation>Le dictionnaire pour la langue %1 est introuvable.</translation>
    </message>
    <message>
        <source>Move to &apos;Checked&apos;</source>
        <translation>Aller à &apos;Vérifié&apos;</translation>
    </message>
    <message>
        <source>Available languages</source>
        <translation>Langues disponibles</translation>
    </message>
    <message>
        <source>Move to &apos;Available languages&apos;</source>
        <translation>Aller à &apos;Langues disponibles&apos;</translation>
    </message>
    <message>
        <source>Checked</source>
        <translation>Vérifié</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
</context>
</TS>
